/*************************************************************************
 *
 *  $RCSfile: slider.hxx,v $
 *
 *  $Revision: 1.1.1.1 $
 *
 *  last change: $Author: hr $ $Date: 2000/09/19 10:23:07 $
 *
 *  The Contents of this file are made available subject to the terms of
 *  either of the following licenses
 *
 *         - GNU Lesser General Public License Version 2.1
 *         - Sun Industry Standards Source License Version 1.1
 *
 *  Sun Microsystems Inc., October, 2000
 *
 *  GNU Lesser General Public License Version 2.1
 *  =============================================
 *  Copyright 2000 by Sun Microsystems, Inc.
 *  901 San Antonio Road, Palo Alto, CA 94303, USA
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *
 *  Sun Industry Standards Source License Version 1.1
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.1 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://www.openoffice.org/license.html.
 *
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 *
 *  The Initial Developer of the Original Code is: Sun Microsystems, Inc.
 *
 *  Copyright: 2000 by Sun Microsystems, Inc.
 *
 *  All Rights Reserved.
 *
 *  Contributor(s): _______________________________________
 *
 *
 ************************************************************************/

#ifndef _SV_SLIDER_HXX
#define _SV_SLIDER_HXX

#ifndef _SV_SV_H
#include <vcl/sv.h>
#endif
#ifndef _SV_CTRL_HXX
#include <vcl/ctrl.hxx>
#endif
// for enum ScrollType
#ifndef _SV_SCRBAR_HXX
#include <vcl/scrbar.hxx>
#endif

// ----------
// - Slider -
// ----------

class Slider : public Control
{
private:
	Rectangle		maChannel1Rect;
	Rectangle		maChannel2Rect;
	Rectangle		maThumbRect;
	long			mnStartPos;
	long			mnMouseOff;
	long			mnThumbPixOffset;
	long			mnThumbPixRange;
	long			mnThumbPixPos;
	long			mnChannelPixOffset;
	long			mnChannelPixRange;
	long			mnChannelPixTop;
	long			mnChannelPixBottom;
	long			mnMinRange;
	long			mnMaxRange;
	long			mnThumbPos;
	long			mnLineSize;
	long			mnPageSize;
	long			mnDelta;
	USHORT			mnDragDraw;
	USHORT			mnStateFlags;
	ScrollType		meScrollType;
	BOOL			mbCalcSize;
	BOOL			mbFullDrag;
	Link			maSlideHdl;
	Link			maEndSlideHdl;

#ifdef _SV_SLIDER_CXX
	void			ImplInit( Window* pParent, WinBits nStyle );
	void			ImplInitStyle( WinBits nStyle );
	void			ImplLoadRes( const ResId& rResId );
	void			ImplInitSettings();
	void			ImplUpdateRects( BOOL bUpdate = TRUE );
	long			ImplCalcThumbPos( long nPixPos );
	long			ImplCalcThumbPosPix( long nPos );
	void			ImplCalc( BOOL bUpdate = TRUE );
	void			ImplDraw( USHORT nDrawFlags );
	BOOL			ImplIsPageUp( const Point& rPos );
	BOOL			ImplIsPageDown( const Point& rPos );
	long			ImplSlide( long nNewPos, BOOL bCallEndSlide );
	long			ImplDoAction( BOOL bCallEndSlide );
	void			ImplDoMouseAction( const Point& rPos, BOOL bCallAction = TRUE );
	long			ImplDoSlide( long nNewPos );
	long			ImplDoSlideAction( ScrollType eScrollType );
#endif

public:
					Slider( Window* pParent, WinBits nStyle = WB_HORZ );
					Slider( Window* pParent, const ResId& rResId );

	virtual void	MouseButtonDown( const MouseEvent& rMEvt );
	virtual void	Tracking( const TrackingEvent& rTEvt );
	virtual void	KeyInput( const KeyEvent& rKEvt );
	virtual void	Paint( const Rectangle& rRect );
	virtual void	Resize();
	virtual void	RequestHelp( const HelpEvent& rHEvt );
	virtual void	StateChanged( StateChangedType nType );
	virtual void	DataChanged( const DataChangedEvent& rDCEvt );

	virtual void	Slide();
	virtual void	EndSlide();

	void			EnableDrag( BOOL bEnable = TRUE )
						{ mbFullDrag = bEnable; }
	BOOL			IsDragEnabled() const { return mbFullDrag; }

	void			SetRangeMin( long nNewRange );
	long			GetRangeMin() const { return mnMinRange; }
	void			SetRangeMax( long nNewRange );
	long			GetRangeMax() const { return mnMaxRange; }
	void			SetRange( const Range& rRange );
	Range			GetRange() const { return Range( GetRangeMin(), GetRangeMax() ); }
	void			SetThumbPos( long nThumbPos );
	long			GetThumbPos() const { return mnThumbPos; }
	void			SetLineSize( long nNewSize ) { mnLineSize = nNewSize; }
	long			GetLineSize() const { return mnLineSize; }
	void			SetPageSize( long nNewSize ) { mnPageSize = nNewSize; }
	long			GetPageSize() const { return mnPageSize; }

	long			GetDelta() const { return mnDelta; }

	Size			CalcWindowSizePixel();

	void			SetSlideHdl( const Link& rLink ) { maSlideHdl = rLink; }
	const Link& 	GetSlideHdl() const { return maSlideHdl;	}
	void			SetEndSlideHdl( const Link& rLink ) { maEndSlideHdl = rLink; }
	const Link& 	GetEndSlideHdl() const { return maEndSlideHdl; }
};

#endif // _SV_SLIDER_HXX
